@@ -3,26 +3,20 @@ require 'r10k/action/cri_runner'
 module R10K
   module Action
     module Puppetfile
-      # Extend the default Cri Runner to use the PUPPETFILE environment
-      # variables.
+      # Extend the default Cri Runner with Puppetfile specific opts
       #
       # @api private
-      # @deprecated The use of these environment variables is deprecated and
-      #   will be removed in 2.0.0.
       class CriRunner < R10K::Action::CriRunner
+
+        include R10K::Logging
+
         def handle_opts(opts)
           opts[:root]       ||= wd
-          opts[:moduledir]  ||= env['PUPPETFILE_DIR']
-          opts[:puppetfile] ||= env['PUPPETFILE']
           super(opts)
         end
 
         private
 
-        def env
-          ENV
-        end
-
         def wd
           Dir.getwd
         end
