@@ -11,9 +11,9 @@ describe R10K::Module do
 
   describe 'delegating to R10K::Module::Forge' do
     [
-      ['bar/quux', []],
-      ['bar-quux', []],
-      ['bar/quux', ['8.0.0']],
+      ['bar/quux', nil],
+      ['bar-quux', nil],
+      ['bar/quux', '8.0.0'],
     ].each do |scenario|
       it "accepts a name matching #{scenario[0]} and args #{scenario[1].inspect}" do
         expect(R10K::Module.new(scenario[0], '/modulepath', scenario[1])).to be_a_kind_of(R10K::Module::Forge)
